"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitMQService = void 0;
const messageDefinitions_1 = require("../../services/rabbitmq/messages/messageDefinitions");
const messages_1 = require("./messages");
class RabbitMQService {
    constructor(amqpConnection, options) {
        this.amqpConnection = amqpConnection;
        this.options = options;
    }
    sendCancelOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getCancelOrderMessageDefinition)(), message);
    }
    sendHealthStatusMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getHealthStatusMessageDefinition)(), message);
    }
    sendHealthCheckMessage() {
        this.publishMessage((0, messageDefinitions_1.getHealthCheckMessageDefinition)(), null);
    }
    sendCreateOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getNewOrderMessageDefinition)(message.carrierId), message);
    }
    sendSaveOrderMessage(message) {
        this.publishMessage((0, messageDefinitions_1.getSaveOrderMessageDefinition)(), message);
    }
    sendUpdateOrderMessage(message) {
        this.publishMessage((0, messages_1.getUpdateOrderMessageDefinition)(), message);
    }
    sendTrackingMessage(message) {
        this.publishMessage((0, messages_1.getTrackingMessageDefinition)(message.carrierId), message);
    }
    sendTrackingRequeueMessage(message) {
        this.publishMessage((0, messages_1.getTrackingRequeueMessageDefinition)(message.carrierId), message);
    }
    sendPrintLabelMessage(message) {
        this.publishMessage((0, messages_1.getPrintLabelMessageDefinition)(), message);
    }
    sendOutputOrderStatusMessage(message) {
        this.publishMessage((0, messages_1.getOutputOrderStatusMessageDefinition)(), message);
    }
    sendOutputErrorMessage(message) {
        this.publishMessage((0, messages_1.getOutputOrderStatusMessageDefinition)(), message);
    }
    getOrderById(message) {
        return this.publishMessageRpc((0, messages_1.getOrderGetByIdMessageDefinition)(), message);
    }
    publishMessageRpc(messageDefinition, message) {
        var _a;
        const { exchange, routingKey } = messageDefinition;
        const requestOptions = {
            exchange,
            routingKey,
            payload: message,
            timeout: (_a = this.options) === null || _a === void 0 ? void 0 : _a.defaultRpcTimeoutMs,
        };
        return this.amqpConnection.request(requestOptions);
    }
    publishMessage(messageDefinition, message) {
        const { exchange, routingKey, pattern } = messageDefinition;
        const envelope = {
            pattern,
            data: message,
        };
        this.amqpConnection.publish(exchange, routingKey, envelope);
    }
}
exports.RabbitMQService = RabbitMQService;
//# sourceMappingURL=rabbitmq.service.js.map